@@ -103,6 +103,21 @@ class ObjectStorageContextFileMixin(metaclass=ABCMeta):
         """
         raise NotImplementedError()
 
+    @abstractmethod
+    def hasItemVersionedFiles(
+        self, group: ItemStorageGroupEnum, key: str
+    ) -> bool:
+        """Has Item Versioned File
+
+        Return True if any storage files exist for this item, else returns
+        false. This is for files additional to the storage item.
+
+        :param group: Group to fetch item from
+        :param key: Key of the item to group
+        :return: True for files that exist
+        """
+        raise NotImplementedError()
+
     @abstractmethod
     def getItemVersionedFileContent(
         self, group: ItemStorageGroupEnum, key: str, path: Path
