@@ -123,6 +123,15 @@ class GitObjectStorageContextFileMixin(ObjectStorageContextFileMixin):
         recurse(tree, Path())
         return infos
 
+    def hasItemVersionedFiles(
+        self, group: ItemStorageGroupEnum, key: str
+    ) -> bool:
+        try:
+            self._getTree(self.__makeVersionedPath(group, key))
+            return True
+        except FileNotFoundError:
+            return False
+
     def getItemVersionedFileContent(
         self, group: ItemStorageGroupEnum, key: str, path: Path
     ) -> Optional[VersionedFileContent]:
