@@ -1,6 +1,7 @@
 import logging
 import os
 from pathlib import Path
+from typing import Optional
 
 from mako import exceptions
 from mako.lookup import TemplateLookup
@@ -38,7 +39,7 @@ class ReadmeCompiler:
             return str(
                 rootTemplate.render(
                     makoGlobal={},
-                    metadata=self._context.metadata,
+                    projectMetadata=self._context.metadata,
                     blueprints=blueprints,
                     files=files,
                     params=params,
