@@ -101,6 +101,10 @@ class FileArchiveLargeTuple(FileArchiveTuple):
 
         return listArchiveFiles(self.archivePath)
 
+    @property
+    def hasFiles(self) -> bool:
+        return self.archivePath.exists()
+
     def getFileContent(self, path: Path) -> ArchiveFileContent:
         archivePath = self.archivePath
         if not archivePath.exists():
